#
# spec file for package perl-XML-RSS
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name XML-RSS
Name:           perl-XML-RSS
Version:        1.640.0
Release:        1.1
# 1.64 -> normalize -> 1.640.0
%define cpan_version 1.64
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Creates and updates RSS files
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SH/SHLOMIF/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DateTime::Format::Mail)
BuildRequires:  perl(DateTime::Format::W3CDTF)
BuildRequires:  perl(HTML::Entities)
BuildRequires:  perl(Module::Build) >= 0.28
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(XML::Parser)
Requires:       perl(DateTime::Format::Mail)
Requires:       perl(DateTime::Format::W3CDTF)
Requires:       perl(HTML::Entities)
Requires:       perl(XML::Parser)
Provides:       perl(XML::RSS) = %{version}
Provides:       perl(XML::RSS::Private::Output::Base) = %{version}
Provides:       perl(XML::RSS::Private::Output::Roles::ImageDims) = %{version}
Provides:       perl(XML::RSS::Private::Output::Roles::ModulesElems) = %{version}
Provides:       perl(XML::RSS::Private::Output::V0_9) = %{version}
Provides:       perl(XML::RSS::Private::Output::V0_91) = %{version}
Provides:       perl(XML::RSS::Private::Output::V1_0) = %{version}
Provides:       perl(XML::RSS::Private::Output::V2_0) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This module provides a basic framework for creating and maintaining RDF
Site Summary (RSS) files. This distribution also contains many examples
that allow you to generate HTML from an RSS, convert between 0.9, 0.91,
1.0, and 2.0 version, and other nifty things. This might be helpful if you
want to include news feeds on your Web site from sources like Slashdot and
Freshmeat or if you want to syndicate your own content.

XML::RSS currently supports versions at http://www.rssboard.org/rss-0-9-0,
at http://www.rssboard.org/rss-0-9-1, at http://web.resource.org/rss/1.0/,
and at http://www.rssboard.org/rss-2-0 of RSS.

RSS was originally developed by Netscape as the format for Netscape
Netcenter channels, however, many Web sites have since adopted it as a
simple syndication format. With the advent of RSS 1.0, users are now able
to syndication many different kinds of content including news headlines,
threaded messages, products catalogs, etc.

*Note:* In order to parse and generate dates (such as 'pubDate' and
'dc:date') it is recommended to use DateTime::Format::Mail and
DateTime::Format::W3CDTF , which is what XML::RSS uses internally and
requires. It should also be possible to pass DateTime objects which will be
formatted accordingly. E.g:

    use DateTime ();

    my $dt = DateTime->from_epoch(epoch => 1_500_000_000);

    $rss->channel(
        pubDate => $dt,
        .
        .
        .
    );

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README TODO
%license LICENSE

%changelog
* Wed Oct 16 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.640.0 (1.64)
  see /usr/share/doc/packages/perl-XML-RSS/Changes
  1.64    2024-10-16
  - Avoid double $VERSION
  - https://github.com/shlomif/perl-XML-RSS/pull/23
  - https://github.com/shlomif/perl-XML-RSS/issues/18
  - Thanks to @yoshikazusawa
  - Thanks to @hvds
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Wed Dec 27 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.63
  see /usr/share/doc/packages/perl-XML-RSS/Changes
  1.63    2023-12-26
  - Add allow_empty .
  - https://github.com/shlomif/perl-XML-RSS/issues/20
  - Thanks to @johnhorner .
* Fri Oct 16 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.62
  see /usr/share/doc/packages/perl-XML-RSS/Changes
  1.62    2020-10-15
  - dist.ini / weaver.ini / .tidyallrc / etc. cleanup
  - Move to @SHLOMIF
  - Inspired by Lady_Aleena.
  - Sympotamtic fix for item/link nested inside custom tags:
  - https://github.com/shlomif/perl-XML-RSS/issues/7
  - Thanks to @jkramer for the bug report and a test case.
* Sun Aug 25 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.61
  see /usr/share/doc/packages/perl-XML-RSS/Changes
  1.61    2019-08-24
  - Clarified the docs regarding DateTime objects.
  - Thanks to shtrb
  - Add 2.0 to the version list, fix broken links to versions
  - Thanks to E. Choroba
  - Changed to explicit imports in "use" statements.
* Mon Mar  5 2018 coolo@suse.com
- updated to 1.60
  see /usr/share/doc/packages/perl-XML-RSS/Changes
  1.60    2018-04-03
  - Convert to Dist-Zilla.
  - Add Travis-CI support.
* Tue Mar  8 2016 coolo@suse.com
- updated to 1.59
  see /usr/share/doc/packages/perl-XML-RSS/Changes
  1.59    2016-03-01
  - Merge a pull request to add subcategory support.
  - https://github.com/shlomif/perl-XML-RSS/pull/4
  - https://rt.cpan.org/Public/Bug/Display.html?id=48426
  - Thanks to @ozcoder for the changes.
* Sat Feb 13 2016 coolo@suse.com
- updated to 1.58
  see /usr/share/doc/packages/perl-XML-RSS/Changes
  1.58    2016-02-08
  - Merge a pull-request regarding the handling of isPermaLink:
  - https://github.com/shlomif/perl-XML-RSS/pull/2
  - Thanks to @dwmc15873 for the changes.
* Tue Dec 15 2015 coolo@suse.com
- updated to 1.57
  see /usr/share/doc/packages/perl-XML-RSS/Changes
  1.57    2015-12-13
  - Update an old E-mail address for Shlomi Fish.
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.56
  see /usr/share/doc/packages/perl-XML-RSS/Changes
* Sat May 11 2013 lars@linux-schulserver.de
- update to 1.51:
  + Sort the XML namespaces before outputting
  + Update the repository URL to its new location on GitHub
* Mon Apr 11 2011 vcizek@novell.com
- update to 1.49
  - Some correctness and Modern Perl changes to the rss2html.pl
    script (it still appears to be very hairy.)
  - Add support for parsing rssCloud:
  - https://rt.cpan.org/Ticket/Display.html?id=67241
  - Thanks to STUIFZAND for the patch.
- corrected license to GPL+ or Artistic
* Wed Feb  2 2011 vcizek@novell.com
- bzipped source tarball
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Aug 31 2010 pascal.bleser@opensuse.org
- update to 1.48:
  * fix the $rss->parse($string)->other_method() display (had to add spaces between the << and >>) RT#56848
- changes from 1.47:
  * made sure XML::RSS::save() can do its thing when in taint mode, RT#52334
- changes from 1.46:
  * removed the perl-5.6.x-specific workarounds and made perl-5.8.x as a requirement;
    this was done in order to:
    + avoid a workaround that also caused an incomplete test coverage
    + avoid various test failures due to a problem with XML-Parser on 5.6.x
    + encourage people using ancient versions of perl in production
    + convert all occurences of "new XML::RSS" to "XML::RSS->new()" everywhere
- changes from 1.45:
  * removed some unused module requirements statements from lib/**.pm
- changes from 1.44:
  * add support for multiple enclosures
- changes from 1.42:
  * when transforming elements with attributes into hash-refs - make sure they are placed in the correct namespace
- changes from 1.41:
  * made the default keys for the channel link, description and title undef instead of ''. They become '' once they are opened; RT#40686
  * now keeping track of rdf:resource of <image> in RSS 1.0, RT#3978
  * made sure that channel/{link,description,title} are localized to the empty string before rendering, to allow for better backwards compatibility; RT#40686
- changes from 1.40:
  * now outputting an arrayref of <skipDays>/<day>'s and <skipHours>/<hours> properly; RT#40978
  * now parsing multiple <category>'ies inside an <item> into an array-reference; RT#38296
  * now outputting an arrayref of <item>/<category> properly; RT#38296
  * parsing multiple <channel>/<category> into arrays; RT#9729
  * rendering multiple <channel>/<category> elements from array refs; RT#9729
  * now parsing multiple dc:items into an array reference (at least inside an <item>); RT#6000
  * added the modules_as_arrays option to parse repeatable module elements into an array ref
* Sun Oct 26 2008 gerrit.beine@gmx.de
- update to 1.36
* Sun Jun  8 2008 gerrit.beine@gmx.de
- first release 1.33
